@@ -27,6 +27,8 @@ extensions = [
     'openstackdocstheme',
     'oslo_config.sphinxext',
     'oslo_config.sphinxconfiggen',
+    'oslo_policy.sphinxext',
+    'oslo_policy.sphinxpolicygen',
 ]
 
 # openstackdocstheme options
@@ -95,7 +97,6 @@ blockdiag_html_image_format = "svg"
 
 _config_generator_config_files = [
     'networking-bgpvpn.conf',
-    'opencontrail-driver.conf',
 ]
 
 def _get_config_generator_config_definition(conf_file):
@@ -110,3 +111,8 @@ config_generator_config_file = [
     _get_config_generator_config_definition(conf_file)
     for conf_file in _config_generator_config_files
 ]
+
+# -- Options for oslo_policy.sphinxpolicygen ---------------------------------
+
+policy_generator_config_file = '../../etc/oslo-policy-generator/policy.conf'
+sample_policy_basename = '_static/networking-bgpvpn'
